summaryrefslogtreecommitdiffstats
path: root/net/base
diff options
context:
space:
mode:
authoreroman@chromium.org <eroman@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-05-13 20:20:26 +0000
committereroman@chromium.org <eroman@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-05-13 20:20:26 +0000
commit3368b54748ed06d61ddc35f0cce4190961ec950c (patch)
treeee870d17ac974a61b992bb63672db8c49b871b27 /net/base
parent9058cb1af2c337afdb65640956662d51336c4f98 (diff)
downloadchromium_src-3368b54748ed06d61ddc35f0cce4190961ec950c.zip
chromium_src-3368b54748ed06d61ddc35f0cce4190961ec950c.tar.gz
chromium_src-3368b54748ed06d61ddc35f0cce4190961ec950c.tar.bz2
Minor refactor: rename "extra_parameters" --> "params".
(The "extra" was redundant. And "params" is a well understood abbreviation of "parameters"). Review URL: http://codereview.chromium.org/2110001 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@47183 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'net/base')
-rw-r--r--net/base/net_log.h10
1 files changed, 4 insertions, 6 deletions
diff --git a/net/base/net_log.h b/net/base/net_log.h
index 69676b7..a2a8df2 100644
--- a/net/base/net_log.h
+++ b/net/base/net_log.h
@@ -102,21 +102,19 @@ class NetLog {
// |source| - The source that generated the event.
// |phase| - An optional parameter indicating whether this is the start/end
// of an action.
// |extra_parameters| - Optional (may be NULL) parameters for this event.
// The specific subclass of EventParameters is defined
// by the contract for events of this |type|.
virtual void AddEntry(EventType type,
const base::TimeTicks& time,
const Source& source,
EventPhase phase,
- EventParameters* extra_parameters) = 0;
+ EventParameters* params) = 0;
// Returns a unique ID which can be used as a source ID.
virtual uint32 NextID() = 0;
// Returns true if more complicated messages should be sent to the log.
- // TODO(eroman): This is a carry-over from refactoring; figure out
- // something better.
virtual bool HasListener() const = 0;
// Returns a C-String symbolic name for |event_type|.
@@ -102,21 +102,19 @@ class NetLog {
// |phase| - An optional parameter indicating whether this is the start/end
// of an action.
- // |extra_parameters| - Optional (may be NULL) parameters for this event.
- // The specific subclass of EventParameters is defined
- // by the contract for events of this |type|.
+ // |params| - Optional (may be NULL) parameters for this event.
+ // The specific subclass of EventParameters is defined
+ // by the contract for events of this |type|.
virtual void AddEntry(EventType type,
const base::TimeTicks& time,